Gestione eficazmente sus casos de asistencia en IBM Cloud

Aprenda a gestionar sus casos de asistencia en IBM Cloud, incluido el seguimiento del progreso, la actualización de casos y la gestión de listas de seguimiento para la resolución eficaz de problemas.

Para ver y gestionar los casos de soporte, vaya a la página Gestionar casos. Si es un usuario de infraestructura clásica y no ve una lista de un caso anterior, pulse Ver casos de infraestructura clásica. También puedes obtener una vista rápida de tus 5 casos abiertos actualizados más recientemente escribiendo case status en el asistente de IA IBM Cloud.

También puede ver sus casos de asistencia de IBM en la página Gestionar casos, pero sólo pueden gestionarse en el portal de asistencia de IBM. El acceso para ver estos casos se controla en el portal de asistencia IBM. Para obtener más información sobre el acceso, consulte Gestión del acceso a su cuenta de asistencia.

Visualización de casos de soporte utilizando la API

Puede ver mediante programación un caso de soporte utilizando la API tal como se muestra en la siguiente solicitud de ejemplo. Para obtener más información, consulta la API de gestión de casos.

Para ver un caso, consulte los ejemplos siguientes:

curl -X GET 'https://support-center.cloud.ibm.com/case-management/v1/cases/{case_number}?fields=number,updated_at,resources' -H 'Authorization: TOKEN' \
GetCaseOptions getCaseOptions = new GetCaseOptions.Builder()
  .caseNumber(caseNumber)
  .addFields(GetCaseOptions.Fields.DESCRIPTION)
  .addFields(GetCaseOptions.Fields.STATUS)
  .addFields(GetCaseOptions.Fields.SEVERITY)
  .addFields(GetCaseOptions.Fields.CREATED_BY)
  .build();
Response<Case> response = service.getCase(getCaseOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const fieldsToReturn = [
  CaseManagementV1.GetCaseConstants.Fields.DESCRIPTION,
  CaseManagementV1.GetCaseConstants.Fields.STATUS,
  CaseManagementV1.GetCaseConstants.Fields.SEVERITY,
  CaseManagementV1.GetCaseConstants.Fields.CREATED_BY,
];
const params = {
  caseNumber: caseNumber,
  fields: fieldsToReturn,
};
caseManagementService.getCase(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
fields_to_return = [
  GetCaseEnums.Fields.DESCRIPTION,
  GetCaseEnums.Fields.STATUS,
  GetCaseEnums.Fields.SEVERITY,
  GetCaseEnums.Fields.CREATED_BY,
]
case = case_management_service.get_case(
  case_number=case_number,
  fields=fields_to_return
).get_result()
print(json.dumps(case, indent=2))
getCaseOptions := caseManagementService.NewGetCaseOptions(
  caseNumber,
)
getCaseOptions.SetFields([]string{
  casemanagementv1.GetCaseOptionsFieldsDescriptionConst,
  casemanagementv1.GetCaseOptionsFieldsStatusConst,
  casemanagementv1.GetCaseOptionsFieldsSeverityConst,
  casemanagementv1.GetCaseOptionsFieldsCreatedByConst,
})
caseVar, response, err := caseManagementService.GetCase(getCaseOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Actualización de casos de soporte utilizando la API

La siguiente solicitud de ejemplo muestra cómo actualizar mediante programación un caso de soporte. Para obtener más información, consulta la API de gestión de casos.

curl -X PUT '/case-management/v1/cases/{case_number}/status' -H 'Authorization: TOKEN' -d '{
  "action": "resolve",
  "comment": "The issue is resolved. Thank you!",
  "resolution_code": 1
}'
ResolvePayload statusPayloadModel = new ResolvePayload.Builder()
  .action("resolve")
  .comment("The problem has been resolved.")
  .resolutionCode(1)
  .build();
UpdateCaseStatusOptions updateCaseStatusOptions = new UpdateCaseStatusOptions.Builder()
  .caseNumber(caseNumber)
  .statusPayload(statusPayloadModel)
  .build();
Response<Case> response = service.updateCaseStatus(updateCaseStatusOptions).execute();
Case xCase = response.getResult();
System.out.println(xCase);
const statusPayloadModel = {
  action: 'resolve',
  comment: 'The problem has been resolved.',
  resolution_code: 1,
};
const params = {
  caseNumber: caseNumber,
  statusPayload: statusPayloadModel,
};
caseManagementService.updateCaseStatus(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
status_payload_model = {
  'action': 'resolve',
  'comment': 'The problem has been resolved.',
  'resolution_code': 1,
}
case = case_management_service.update_case_status(
  case_number=case_number,
  status_payload=status_payload_model
).get_result()
print(json.dumps(case, indent=2))
statusPayloadModel := &casemanagementv1.ResolvePayload{
  Action:         core.StringPtr("resolve"),
  Comment:        core.StringPtr("The problem has been resolved."),
  ResolutionCode: core.Int64Ptr(int64(1)),
}
updateCaseStatusOptions := caseManagementService.NewUpdateCaseStatusOptions(
  caseNumber,
  statusPayloadModel,
)
caseVar, response, err := caseManagementService.UpdateCaseStatus(updateCaseStatusOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(caseVar, "", "  ")
fmt.Println(string(b))

Adición de comentarios a casos de soporte utilizando la API

La siguiente solicitud de ejemplo muestra cómo añadir mediante programación un comentario a un caso de soporte. Para obtener más información, consulta la API de gestión de casos.

curl -X PUT '/case-management/v1/cases/{case_number}/comments' -H 'Authorization: TOKEN' -d '{
  "comment": "Test comment api"
}'
AddCommentOptions addCommentOptions = new AddCommentOptions.Builder()
  .caseNumber(caseNumber)
  .comment("This is an example comment.")
  .build();
Response<Comment> response = service.addComment(addCommentOptions).execute();
Comment comment = response.getResult();
System.out.println(comment);
const params = {
  caseNumber: caseNumber,
  comment: 'This is an example comment,',
};
caseManagementService.addComment(params)
  .then(res => {
    console.log(JSON.stringify(res.result, null, 2));
  })
  .catch(err => {
    console.warn(err)
  });
comment = case_management_service.add_comment(
  case_number=case_number,
  comment='This is an example comment.'
).get_result()
print(json.dumps(comment, indent=2))
addCommentOptions := caseManagementService.NewAddCommentOptions(
  caseNumber,
  "This is an example comment.",
)
comment, response, err := caseManagementService.AddComment(addCommentOptions)
if err != nil {
  panic(err)
}
b, _ := json.MarshalIndent(comment, "", "  ")
fmt.Println(string(b))

Actualización de los casos de asistencia

Seleccione el número de caso para actualizar el caso de asistencia. Puede añadir un comentario, adjuntar o eliminar archivos, añadir recursos o actualizar la lista de seguimiento. Para actualizar tu caso de soporte técnico, sigue estos pasos:

  1. En la barra de menús de la consola IBM Cloud, haga clic en el icono Ayuda > Centro de soporte.
  2. Selecciona el caso de asistencia en el mosaico Casos de asistencia recientes.
  3. Añada un comentario y haga clic en Enviar.
  4. Si lo desea, puede actualizar los siguientes campos:
    • Añadir un usuario a la lista de seguimiento
    • Adjuntar o eliminar archivos
    • Añadir un recurso específico para un caso de asistencia técnica

Añadir un CRN al comentario de un caso

Añadir detalles sobre los recursos específicos relacionados con un caso de asistencia permite un triaje, una investigación y una resolución más eficientes. Para ver y copiar un nombre de recurso de nube (CRN) para añadirlo a un caso de soporte, siga estos pasos:

  1. Desde la consola de IBM Cloud®, haz clic en el icono del menú de navegación, luego en > Lista de recursos para ver tu lista de recursos.
  2. Despliegue las secciones para localizar la instancia de servicio para la que desea recuperar el CRN.
  3. Pulse la fila de la tabla. Esta acción abre el panel lateral de la tabla de recursos, donde puede ver el CRN.
  4. Seleccione Copiar al portapapeles junto al valor CRN.
  5. Pegue el valor en un comentario en el caso de asistencia.

Actualización de la lista de observación del caso de soporte

Puede actualizar qué usuarios de su cuenta pueden recibir notificaciones sobre su caso de soporte añadiéndolos a la lista de observación. Se pueden añadir usuarios a la lista de seguimiento al crear un caso de asistencia o una vez creado dicho caso.

De forma predeterminada, los usuarios de la cuenta no tienen acceso para crear, actualizar, buscar o ver casos. El titular de la cuenta debe proporcionar acceso a los usuarios asignándoles una política de acceso de Identity and Access Management (IAM). Para obtener más información, consulte Asignación de acceso de usuario para trabajar con casos de soporte.

Para asegurarse de que se notifican a los usuarios las actualizaciones de un caso de soporte existente que ha creado, siga estos pasos para añadirlos a la lista de observación.

  1. En la barra de menús de la consola IBM Cloud, haga clic en el icono Ayuda > Centro de soporte.

  2. Selecciona el caso de asistencia en el mosaico Casos de asistencia recientes.

  3. En la sección Lista de seguimiento, haz clic en el icono deconfiguración.

  4. Seleccione los usuarios que están en la cuenta para añadirlos a la lista de observación.

    Los usuarios que se añaden a la lista de observación deben ser miembros de la cuenta en la que se ha creado el caso. Para obtener más información sobre la asignación de acceso de usuarios a su cuenta, consulte Adición de usuarios al grupo de acceso de gestión de casos.

Tipos de estados de casos de soporte

Cuando se necesita la respuesta a una actualización en el caso de soporte, el estado se visualiza como Waiting on client. Si no proporciona una respuesta dentro de siete días, el estado se actualiza a Resolved. Si sigue sin haber respuesta durante siete días más, el caso se cierra. Para obtener una descripción de cada tipo de estado, consulte la tabla siguiente:

Tipos de estados de casos de soporte
Estado Descripción
Nuevo Un caso creado aún no visto por un ingeniero de soporte.
En curso Un caso que se está revisando.
En espera de respuesta del cliente El técnico de soporte ha enviado una consulta sobre el caso que requiere la respuesta del usuario.
Se ha proporcionado una resolución El ingeniero de soporte ha ofrecido una resolución que el usuario debe realizar.
Resuelto Se considera que el caso de soporte ha finalizado y está listo para cerrarse.
Cerrado Un ingeniero de soporte ha cerrado el caso y no se puede reabrir.

Escalado de casos de soporte

Con un plan de asistencia de pago, puedes utilizar el proceso de escalado para señalar problemas críticos y expresar tus inquietudes sobre un caso de asistencia. Cuando un caso se escala, el equipo de soporte de IBM Cloud revisa la información del caso de soporte y responde con las actualizaciones adecuadas. Para obtener información sobre la gravedad de los casos, consulte Gravedad del caso y tiempos de respuesta inicial.

Para escalar un caso, complete los pasos siguientes:

  1. Póngase en contacto con el servicio de asistencia IBM Cloud por chat o por teléfono.
  2. Proporcione el número de caso existente y una solicitud para escalar el caso.
  3. Proporcione la justificación de un escalado y explique el impacto empresarial de su problema o cuestión.

Planes de asistencia básicos: Si tienes un plan de asistencia Basic, el acceso a la asistencia se realiza únicamente a través de casos no técnicos. Si su consulta de asistencia requiere una respuesta más inmediata, considere la posibilidad de actualizar a un plan de asistencia Premium o Avanzado para poder asignar un nivel de gravedad a un caso. Para ampliar tu plan de asistencia, crea un caso en el Centro de asistencia o ponte en contacto con un representante de ventas de IBM Cloud para que te ayude.

Búsqueda de casos de soporte

Desde la página Gestionar casos, puede filtrar por estado del caso y buscar todos sus casos de asistencia técnica utilizando los parámetros de consulta de la barra de búsqueda. Los filtros por defecto están configurados para ver sólo los casos abiertos. Para ver los casos resueltos o cerrados, actualice el filtro de estado. Todos los parámetros se pueden utilizar conjuntamente e introducir en cualquier orden. También puede filtrar casos seleccionando Todos los casos, Mis casos y Casos de la lista de seguimiento.

Consulte la tabla siguiente para obtener detalles sobre los parámetros de búsqueda:

Parámetros y opciones de búsqueda
Parámetro Opción regla
number número de caso de destino Este parámetro no se puede utilizar con otros parámetros. Si se utiliza el parámetro number, se ignoran todos los demás parámetros y opciones. El parámetro number no rellena automáticamente la búsqueda. Debe utilizar todo el número de caso para iniciar la búsqueda.
sort number
subject
severity
updatedAt
Solo se puede utilizar una de las opciones sort simultáneamente. Puede utilizar el prefijo ~ para revertir el orden de clasificación.
status new
inProgress
waitingOnClient
resolutionProvided
resolved
closed
Se puede utilizar cualquier número de opciones. Las opciones disponibles se pueden especificar como status:new,inProgress o como status:new status:inProgress.
page página de destino a visualizar Si ha obtenido varios resultados con la búsqueda y abarca varias páginas, puede ver los resultados de cualquier página del resultado. Por ejemplo, para ver la página 5 de 10, utilice page:5.
pageSize 10
25
50
100
El tamaño de la página que se visualizará. El tamaño de la página se refiere al número de resultados que quiere cargar.

Si especifica un término sin un parámetro, se muestran los resultados de la búsqueda para el número del caso de soporte y el sujeto del caso.

Ejemplos de consulta y URL

Puedes introducir consultas de búsqueda en la barra de búsqueda indicando un parámetro y una opción separados por dos puntos (:) o puedes utilizar parámetros en un URL para ir directamente a un caso específico o a un grupo de casos en la página Gestionar casos.

Para utilizar parámetros en el URL, añade un signo de interrogación (?) al final de URL. A continuación, establezca el parámetro igual a la opción que seleccione. También puedes separar los parámetros adicionales con un símbolo &.

Para buscar un caso por palabra clave, puede especificar la palabra en la barra de búsqueda sin un parámetro. Para buscar una palabra clave con el URL, utilice search como parámetro y establézcalo igual a la palabra clave, por ejemplo, search=server.

Buscar por número de caso

Especifique lo siguiente para buscar casos de soporte por número de caso:

Consulta
number:CS1234567
URL
https://cloud.ibm.com/unifiedsupport/cases?number=CS1234567

Búsqueda con varios parámetros

Es posible que desee buscar casos de soporte nuevos y en curso, limitar los resultados a 25 por página y visualizados por gravedad. También sabe que el caso que está buscando no va a estar en el primer par de páginas, por lo que desea empezar en la página 5. Escriba la siguiente consulta de búsqueda:

Consulta
status:new,inProgress page:5 pageSize:25 sort:severity
URL
https://cloud.ibm.com/unifiedsupport/cases?status=new&status=inProgress&pageSize=25&sort=severity

Búsqueda de casos resueltos

Especifique la siguiente consulta para ver todos los casos resueltos en función de cuándo se han actualizado por última vez:

Consulta
sort:~updatedAT status:resolved
URL
https://cloud.ibm.com/unifiedsupport/cases?sort=~updatedAT&status=resolved

Creación y gestión de etiquetas de casos

Puede crear y gestionar etiquetas personalizadas que pueden adjuntarse a los casos de asistencia. Estas etiquetas ayudan a clasificar los casos por servicio, incidencia o cualquier lógica personalizada, lo que simplifica la búsqueda, el filtrado y la gestión de grandes volúmenes de interacciones de asistencia.

Para utilizar las etiquetas, la cuenta del cliente debe tener un nivel de asistencia Premium.

Crear etiquetas en su cuenta

Antes de poder etiquetar casos, debe crear etiquetas a nivel de cuenta. Para ello, complete los pasos siguientes:

  1. Vaya a Soporte > Gestionar casos.
  2. Haz clic en Editar etiquetas para añadir tantas etiquetas como necesites. Estas etiquetas son personalizables y pueden reflejar servicios, incidentes, equipos o cualquier otra clasificación relevante para su organización.
  3. Pulse Guardar.

Cada etiqueta debe ser alfanumérica y no superar los 40 caracteres, y puede adjuntar hasta 20 etiquetas a un solo caso de asistencia.

Gestión de etiquetas en tu cuenta

Una vez creadas las etiquetas, puede asociarlas a un caso haciendo clic en Etiquetas de caso y, a continuación, eliminar etiquetas utilizando la misma interfaz.

Para encontrar casos con etiquetas específicas, haga clic en una o más etiquetas. Por ejemplo, haga clic en tag100 o tag100 y tag102 para ver todos los casos asociados.

Sólo se muestran los casos que contienen todas las etiquetas seleccionadas, ya que la opción de búsqueda utiliza una condición Y. No se admite el filtrado OR.

Recibir notificaciones de casos abiertos mediante un perfil de confianza

Cuando trabajas con un perfil de confianza y abres un caso de asistencia, puedes elegir entre dos opciones para recibir notificaciones.

Opción 1: Las notificaciones pueden enviarse a su dirección de correo electrónico.

Opción 2: Las notificaciones pueden enviarse a la dirección de correo electrónico asociada al perfil de confianza.

Para utilizar la segunda opción, se debe asociar al perfil de confianza una dirección de correo electrónico que no sea un ID de servicio, un recurso en la nube o un recurso informático.